package com.hello2morrow.foundation.commandline

import com.hello2morrow.foundation.utilities.OperationResult
import com.hello2morrow.foundation.utilities.OperationResult.IMessageCause

public class ProcessExecutor
{
    private ProcessExecutor()
    {
        //Utility class
    }

    public static String execute(List<String> cmd, OperationResult operationResult, IMessageCause errorCause)
    {
        assert cmd != null & cmd.size() > 0 : "Parameter 'cmd' of method 'execute' must not be empty";
        assert operationResult != null : "Parameter 'operationResult' of method 'execute' must not be null";
        assert errorCause != null : "Parameter 'errorCause' of method 'execute' must not be null";

        def writer = new StringWriter();
        int result = -1;
        try
        {
            final def proc = cmd.execute();
            writer << proc.in;
            writer << proc.err;
            result = proc.waitFor();
        }
        catch (final IOException ex)
        {
            final String content = writer.toString();
            operationResult.addError(errorCause, ex, content);
            return content;
        }

        final String content = writer.toString();
        if (result != 0)
        {
            operationResult.addError(errorCause, content);
        }

        return content;
    }
}